@@ -94,15 +94,20 @@ static void gnome_wp_xml_load_xml (GnomeWPCapplet * capplet,
 				   const gchar * filename) {
   xmlDoc * wplist;
   xmlNode * root, * list, * wpa;
+  gchar * nodelang;
+  const gchar * const * syslangs;
   GdkColor color1, color2;
   GnomeWPItem * item;
+  gint i;
+
+#if GLIB_CHECK_VERSION (2, 6, 0)
+  syslangs = g_get_language_names ();
+#endif
 
   wplist = xmlParseFile (filename);
 
   root = xmlDocGetRootElement (wplist);
 
-  g_return_if_fail (root != NULL);
-
   for (list = root->children; list != NULL; list = list->next) {
     if (!strcmp (list->name, "wallpaper")) {
       GnomeWPItem * wp;
@@ -120,7 +125,19 @@ static void gnome_wp_xml_load_xml (GnomeWPCapplet * capplet,
 	  }
 	} else if (!strcmp (wpa->name, "name")) {
 	  if (wpa->last != NULL) {
-	    wp->name = g_strdup (g_strstrip (wpa->last->content));
+	    nodelang = xmlNodeGetLang (wpa->last);
+
+	    if (wp->name == NULL && nodelang == NULL) {
+	       wp->name = g_strdup (g_strstrip (wpa->last->content));
+            } else {
+	       for (i = 0; syslangs[i] != NULL; i++) {
+	         if (!strcmp (syslangs[i], nodelang)) {
+	           wp->name = g_strdup (g_strstrip (wpa->last->content));
+	         }
+	       }
+	    }
+
+	    xmlFree (nodelang);
 	  }
 	} else if (!strcmp (wpa->name, "imguri")) {
 	  if (wpa->last != NULL) {
